summaryrefslogtreecommitdiff
path: root/include/connectivity/sqlerror.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/connectivity/sqlerror.hxx')
-rw-r--r--include/connectivity/sqlerror.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/connectivity/sqlerror.hxx b/include/connectivity/sqlerror.hxx
index 9b4c60c49476..9b75657290f4 100644
--- a/include/connectivity/sqlerror.hxx
+++ b/include/connectivity/sqlerror.hxx
@@ -22,7 +22,7 @@
#include <com/sun/star/sdbc/SQLException.hpp>
#include <connectivity/dbtoolsdllapi.hxx>
-#include <boost/optional.hpp>
+#include <o3tl/optional.hxx>
#include <memory>
namespace connectivity
@@ -61,11 +61,11 @@ namespace connectivity
// - optional
/** convenience wrapper around boost::optional, allowing implicit construction
*/
- class ParamValue : public ::boost::optional< OUString >
+ class ParamValue : public ::o3tl::optional< OUString >
{
- typedef ::boost::optional< OUString > base_type;
+ typedef ::o3tl::optional< OUString > base_type;
public:
ParamValue( ) : base_type( ) { }
@@ -61,11 +61,11 @@ namespace connectivity
// - optional
- /** convenience wrapper around boost::optional, allowing implicit construction
+ /** convenience wrapper around o3tl::optional, allowing implicit construction
*/